import * as _algolia_client_common from '@algolia/client-common';
import { ClientOptions } from '@algolia/client-common';

type AppID = {
    /**
     * Algolia application ID to which this Query Suggestions configuration belongs.
     */
    appID?: string;
};

type BaseResponse = {
    /**
     * HTTP status code.
     */
    status?: number;
    /**
     * Details about the response, such as error messages.
     */
    message?: string;
};

type ConfigStatus = {
    /**
     * Name of the Query Suggestions index (case-sensitive).
     */
    indexName?: string;
    /**
     * Whether the creation or update of the Query Suggestions index is in progress.
     */
    isRunning?: boolean;
    /**
     * Date and time when the Query Suggestions index was last built, in RFC 3339 format.
     */
    lastBuiltAt?: string;
    /**
     * Date and time when the Query Suggestions index was last updated successfully.
     */
    lastSuccessfulBuiltAt?: string;
    /**
     * Duration of the last successful build in seconds.
     */
    lastSuccessfulBuildDuration?: string;
};

/**
 * Languages for deduplicating singular and plural suggestions. If specified, only the more popular form is included.
 */
type Languages = string[] | boolean;

/**
 * Facet to use as category.
 */
type Facet = {
    /**
     * Facet name.
     */
    attribute?: string;
    /**
     * Number of suggestions.
     */
    amount?: number;
};

/**
 * Configuration of an Algolia index for Query Suggestions.
 */
type SourceIndex = {
    /**
     * Name of the Algolia index (case-sensitive) to use as source for query suggestions.
     */
    indexName: string;
    /**
     * If true, Query Suggestions uses all replica indices to find popular searches. If false, only the primary index is used.
     */
    replicas?: boolean;
    analyticsTags?: string[] | null;
    facets?: Facet[] | null;
    /**
     * Minimum number of hits required to be included as a suggestion.  A search query must at least generate `minHits` search results to be included in the Query Suggestions index.
     */
    minHits?: number;
    /**
     * Minimum letters required to be included as a suggestion.  A search query must be at least `minLetters` long to be included in the Query Suggestions index.
     */
    minLetters?: number;
    generate?: string[][] | null;
    external?: string[] | null;
};

/**
 * Query Suggestions configuration.
 */
type Configuration = {
    /**
     * Algolia indices from which to get the popular searches for query suggestions.
     */
    sourceIndices: SourceIndex[];
    languages?: Languages;
    exclude?: string[] | null;
    /**
     * Whether to turn on personalized query suggestions.
     */
    enablePersonalization?: boolean;
    /**
     * Whether to include suggestions with special characters.
     */
    allowSpecialCharacters?: boolean;
};

/**
 * Query Suggestions configuration.
 */
type ConfigurationWithIndex = Configuration & Record<string, unknown>;

/**
 * API response for retrieving Query Suggestions configurations.
 */
type ConfigurationResponse = AppID & ConfigurationWithIndex;

/**
 * Error.
 */
type ErrorBase = Record<string, any> & {
    message?: string;
};

/**
 * Type of log entry.  - `SKIP`. A query is skipped because it doesn\'t match the conditions for successful inclusion. For example, when a query doesn\'t generate enough search results. - `INFO`. An informative log entry. - `ERROR`. The Query Suggestions process encountered an error.
 */
type LogLevel = 'ERROR' | 'INFO' | 'SKIP';

type LogFile = {
    /**
     * Date and time of the log entry, in RFC 3339 format.
     */
    timestamp?: string;
    level?: LogLevel;
    /**
     * Details about this log entry.
     */
    message?: string;
    /**
     * Level indicating the position of a suggestion in a hierarchy of records.  For example, a `contextLevel` of 1 indicates that this suggestion belongs to a previous suggestion with `contextLevel` 0.
     */
    contextLevel?: number;
};

/**
 * Properties for the `customDelete` method.
 */
type CustomDeleteProps = {
    /**
     * Path of the endpoint, anything after \"/1\" must be specified.
     */
    path: string;
    /**
     * Query parameters to apply to the current query.
     */
    parameters?: Record<string, any>;
};
/**
 * Properties for the `customGet` method.
 */
type CustomGetProps = {
    /**
     * Path of the endpoint, anything after \"/1\" must be specified.
     */
    path: string;
    /**
     * Query parameters to apply to the current query.
     */
    parameters?: Record<string, any>;
};
/**
 * Properties for the `customPost` method.
 */
type CustomPostProps = {
    /**
     * Path of the endpoint, anything after \"/1\" must be specified.
     */
    path: string;
    /**
     * Query parameters to apply to the current query.
     */
    parameters?: Record<string, any>;
    /**
     * Parameters to send with the custom request.
     */
    body?: Record<string, unknown>;
};
/**
 * Properties for the `customPut` method.
 */
type CustomPutProps = {
    /**
     * Path of the endpoint, anything after \"/1\" must be specified.
     */
    path: string;
    /**
     * Query parameters to apply to the current query.
     */
    parameters?: Record<string, any>;
    /**
     * Parameters to send with the custom request.
     */
    body?: Record<string, unknown>;
};
/**
 * Properties for the `deleteConfig` method.
 */
type DeleteConfigProps = {
    /**
     * Query Suggestions index name.
     */
    indexName: string;
};
/**
 * Properties for the `getConfig` method.
 */
type GetConfigProps = {
    /**
     * Query Suggestions index name.
     */
    indexName: string;
};
/**
 * Properties for the `getConfigStatus` method.
 */
type GetConfigStatusProps = {
    /**
     * Query Suggestions index name.
     */
    indexName: string;
};
/**
 * Properties for the `getLogFile` method.
 */
type GetLogFileProps = {
    /**
     * Query Suggestions index name.
     */
    indexName: string;
};
/**
 * Properties for the `updateConfig` method.
 */
type UpdateConfigProps = {
    /**
     * Query Suggestions index name.
     */
    indexName: string;
    configuration: Configuration;
};

declare const apiClientVersion = "5.2.4";
declare const REGIONS: readonly ["eu", "us"];
type Region = (typeof REGIONS)[number];

/**
 * The client type.
 */
type QuerySuggestionsClient = ReturnType<typeof querySuggestionsClient>;
declare function querySuggestionsClient(appId: string, apiKey: string, region: Region, options?: ClientOptions): {
    transporter: _algolia_client_common.Transporter;
    appId: string;
    clearCache(): Promise<void>;
    _ua: string;
    addAlgoliaAgent(segment: string, version?: string): void;
    createConfig(configurationWithIndex: ConfigurationWithIndex, requestOptions?: _algolia_client_common.RequestOptions): Promise<BaseResponse>;
    customDelete({ path, parameters }: CustomDeleteProps, requestOptions?: _algolia_client_common.RequestOptions): Promise<Record<string, unknown>>;
    customGet({ path, parameters }: CustomGetProps, requestOptions?: _algolia_client_common.RequestOptions): Promise<Record<string, unknown>>;
    customPost({ path, parameters, body }: CustomPostProps, requestOptions?: _algolia_client_common.RequestOptions): Promise<Record<string, unknown>>;
    customPut({ path, parameters, body }: CustomPutProps, requestOptions?: _algolia_client_common.RequestOptions): Promise<Record<string, unknown>>;
    deleteConfig({ indexName }: DeleteConfigProps, requestOptions?: _algolia_client_common.RequestOptions): Promise<BaseResponse>;
    getAllConfigs(requestOptions?: _algolia_client_common.RequestOptions): Promise<ConfigurationResponse[]>;
    getConfig({ indexName }: GetConfigProps, requestOptions?: _algolia_client_common.RequestOptions): Promise<ConfigurationResponse>;
    getConfigStatus({ indexName }: GetConfigStatusProps, requestOptions?: _algolia_client_common.RequestOptions): Promise<ConfigStatus>;
    getLogFile({ indexName }: GetLogFileProps, requestOptions?: _algolia_client_common.RequestOptions): Promise<LogFile>;
    updateConfig({ indexName, configuration }: UpdateConfigProps, requestOptions?: _algolia_client_common.RequestOptions): Promise<BaseResponse>;
};

export { type AppID, type BaseResponse, type ConfigStatus, type Configuration, type ConfigurationResponse, type ConfigurationWithIndex, type CustomDeleteProps, type CustomGetProps, type CustomPostProps, type CustomPutProps, type DeleteConfigProps, type ErrorBase, type Facet, type GetConfigProps, type GetConfigStatusProps, type GetLogFileProps, type Languages, type LogFile, type LogLevel, type QuerySuggestionsClient, type Region, type SourceIndex, type UpdateConfigProps, apiClientVersion, querySuggestionsClient };
